@@ -4,28 +4,27 @@ describe 'glance::api' do
 
   let :default_params do
     {
-      :verbose                  => false,
       :debug                    => false,
-      :use_stderr               => true,
-      :bind_host                => '0.0.0.0',
+      :use_stderr               => '<SERVICE DEFAULT>',
+      :bind_host                => '<SERVICE DEFAULT>',
       :bind_port                => '9292',
       :registry_host            => '0.0.0.0',
-      :registry_port            => '9191',
-      :registry_client_protocol => 'http',
+      :registry_port            => '<SERVICE DEFAULT>',
+      :registry_client_protocol => '<SERVICE DEFAULT>',
       :log_file                 => '/var/log/glance/api.log',
       :log_dir                  => '/var/log/glance',
       :auth_type                => 'keystone',
       :auth_region              => '<SERVICE DEFAULT>',
       :enabled                  => true,
       :manage_service           => true,
-      :backlog                  => '4096',
+      :backlog                  => '<SERVICE DEFAULT>',
       :workers                  => '7',
       :keystone_tenant          => 'services',
       :keystone_user            => 'glance',
       :keystone_password        => 'ChangeMe',
       :token_cache_time         => '<SERVICE DEFAULT>',
       :memcached_servers        => '<SERVICE DEFAULT>',
-      :show_image_direct_url    => false,
+      :show_image_direct_url    => '<SERVICE DEFAULT>',
       :show_multiple_locations  => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
       :purge_config             => false,
@@ -47,7 +46,6 @@ describe 'glance::api' do
   shared_examples_for 'glance::api' do
     [{:keystone_password => 'ChangeMe'},
      {
-        :verbose                  => true,
         :debug                    => true,
         :bind_host                => '127.0.0.1',
         :bind_port                => '9222',
@@ -154,6 +152,12 @@ describe 'glance::api' do
           is_expected.to contain_glance_api_config('DEFAULT/registry_client_key_file').with_value('<SERVICE DEFAULT>')
         end
 
+        it 'passes purge to resource' do
+          is_expected.to contain_resources('glance_api_config').with({
+            :purge => false
+          })
+        end
+
         it 'is_expected.to configure itself for keystone if that is the auth_type' do
           if params[:auth_type] == 'keystone'
             is_expected.to contain('paste_deploy/flavor').with_value('keystone+cachemanagement')
